@@ -12,8 +12,7 @@
 #' thus summarised by age groups.
 #' @param sample An integer to sample the tables to only that number of records.
 #' If NULL no sample is done.
-#' @param dateRange A list containing the minimum and the maximum dates
-#' defining the time range within which the analysis is performed.
+#' @inheritParams dateRange-startDate
 #'
 #' @return A summarised_result object with results overall and, if specified, by
 #' strata.
@@ -101,10 +100,8 @@ summariseConceptIdCounts <- function(cdm,
       ) |>
       # summarise results
       summariseCountsInternal(stratax, counts) |>
-      dplyr::mutate(omop_table = .env$table,
-                    estimate_name = dplyr::if_else(.data$estimate_name == "count_records", "Number records",
-                                                   dplyr::if_else(.data$estimate_name == "count_subjects", "Number subjects", .data$estimate_name)
-                    ))
+       dplyr::mutate(omop_table = .env$table)
+
 
     omopgenerics::dropSourceTable(cdm = cdm, name = dplyr::starts_with(prefix))
 
